@@ -1,8 +1,6 @@
 import langchain.prompts as prompts
-import langchain.chains as chains
-import langchain.llms as llms
 
-_distill_prompt = prompts.PromptTemplate(
+summary_prompt = prompts.PromptTemplate(
     input_variables=["question", "context_str"],
     template="Provide relevant information that will help answer a question from the context below. "
     "Summarize the information in an unbiased tone. Use direct quotes "
@@ -15,23 +13,11 @@ _distill_prompt = prompts.PromptTemplate(
     "Question: {question}\n"
     "Relevant Information Summary:",
 )
-distill_chain = chains.LLMChain(
-    llm=llms.OpenAI(temperature=0.1), prompt=_distill_prompt
-)
 
-_query_prompt = prompts.PromptTemplate(
-    input_variables=["question"],
-    template="I would like to find scholarly papers to answer this question: {question}. "
-    'A search query that would bring up papers related to this answer would be: "',
-)
-query_chain = chains.LLMChain(
-    llm=llms.OpenAI(temperature=0.05, model_kwargs={"stop": ['"']}),
-    prompt=_query_prompt,
-)
 
-_qa_prompt = prompts.PromptTemplate(
-    input_variables=["question", "context_str"],
-    template="Write a comprehensive answer (about 100 words) "
+qa_prompt = prompts.PromptTemplate(
+    input_variables=["question", "context_str", "length"],
+    template="Write a comprehensive answer ({length}) "
     "for the question below solely based on the provided context. "
     "If the context is insufficient "
     'answer, reply "I cannot answer". '
@@ -46,4 +32,11 @@ _qa_prompt = prompts.PromptTemplate(
     "Question: {question}\n"
     "Answer: ",
 )
-qa_chain = chains.LLMChain(llm=llms.OpenAI(temperature=0.1), prompt=_qa_prompt)
+
+edit_prompt = prompts.PromptTemplate(
+    input_variables=["question", "answer"],
+    template="The original question is: {question} "
+    "We have been provided the following answer: {answer} "
+    "Part of it may be truncated, please edit the answer to make it complete. "
+    "If it appears to be complete, repeat it unchanged.\n\n",
+)
