@@ -3,6 +3,7 @@ import requests
 import os
 import pickle
 from paperqa.utils import strings_similarity
+from langchain.llms import OpenAI
 
 
 def test_maybe_is_text():
@@ -11,7 +12,7 @@ def test_maybe_is_text():
     )
     assert not paperqa.maybe_is_text("\\C0\\C0\\B1\x00")
     # get front page of wikipedia
-    r = requests.get("https://en.wikipedia.org/wiki/Main_Page")
+    r = requests.get("https://en.wikipedia.org/wiki/National_Flag_of_Canada_Day")
     assert paperqa.maybe_is_text(r.text)
 
     # now force it to contain lots of weird encoding
@@ -23,9 +24,10 @@ def test_docs():
     doc_path = "example.txt"
     with open(doc_path, "w", encoding="utf-8") as f:
         # get front page of wikipedia
-        r = requests.get("https://en.wikipedia.org/wiki/Main_Page")
+        r = requests.get("https://en.wikipedia.org/wiki/National_Flag_of_Canada_Day")
         f.write(r.text)
-    docs = paperqa.Docs()
+    llm = OpenAI(temperature=0.1, model_name="text-ada-001")
+    docs = paperqa.Docs(llm=llm)
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     assert docs.docs[doc_path]["key"] == "Wiki2023"
     os.remove(doc_path)
@@ -37,7 +39,7 @@ def test_evidence():
         # get wiki page about politician
         r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
         f.write(r.text)
-    docs = paperqa.Docs()
+    docs = paperqa.Docs(llm=OpenAI(temperature=0.1, model_name="text-curie-001"))
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     evidence, _ = docs.get_evidence(
         "For which state was he a governor", k=1, max_sources=1
@@ -52,7 +54,7 @@ def test_query():
         # get wiki page about politician
         r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
         f.write(r.text)
-    docs = paperqa.Docs()
+    docs = paperqa.Docs(llm=OpenAI(temperature=0.1, model_name="text-ada-001"))
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     answer = docs.query("What is Frederick Bates's greatest accomplishment?")
     print(answer)
@@ -63,17 +65,21 @@ def test_docs_pickle():
     doc_path = "example.txt"
     with open(doc_path, "w", encoding="utf-8") as f:
         # get front page of wikipedia
-        r = requests.get("https://en.wikipedia.org/wiki/Main_Page")
+        r = requests.get("https://en.wikipedia.org/wiki/National_Flag_of_Canada_Day")
         f.write(r.text)
-    docs = paperqa.Docs()
+    docs = paperqa.Docs(llm=OpenAI(temperature=0.0, model_name="text-babbage-001"))
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     docs_pickle = pickle.dumps(docs)
     docs2 = pickle.loads(docs_pickle)
     assert len(docs.docs) == len(docs2.docs)
     assert (
         strings_similarity(
-            docs.get_evidence("What is the date?", k=1, max_sources=1)[0],
-            docs2.get_evidence("What is the date?", k=1, max_sources=1)[0],
+            docs.get_evidence("What date is flag day in Canada?", k=1, max_sources=1)[
+                0
+            ],
+            docs2.get_evidence("What date is flag day in Canada?", k=1, max_sources=1)[
+                0
+            ],
         )
         > 0.75
     )
@@ -86,7 +92,7 @@ def test_bad_context():
         # get wiki page about politician
         r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
         f.write(r.text)
-    docs = paperqa.Docs()
+    docs = paperqa.Docs(llm=OpenAI(model_name="text-davinci-003"))
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     answer = docs.query("What year was Barack Obama born greatest accomplishment?")
     assert (
@@ -102,7 +108,7 @@ def test_repeat_keys():
         # get wiki page about politician
         r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
         f.write(r.text)
-    docs = paperqa.Docs()
+    docs = paperqa.Docs(llm=OpenAI(temperature=0.0, model_name="text-ada-003"))
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     try:
         docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
@@ -129,7 +135,18 @@ def test_repeat_keys():
 def test_pdf_reader():
     tests_dir = os.path.dirname(os.path.abspath(__file__))
     doc_path = os.path.join(tests_dir, "paper.pdf")
-    docs = paperqa.Docs()
+    docs = paperqa.Docs(llm=OpenAI(temperature=0.0, model_name="text-curie-001"))
     docs.add(doc_path, "Wellawatte et al, XAI Review, 2023")
-    answer = docs.query("What is LIME?")
-    assert "Local Interpretable Model-Agnostic Explanations" in answer.answer
+    answer = docs.query("Are counterfactuals actionable (yes/no)?")
+    assert "yes" in answer.answer or "Yes" in answer.answer
+
+
+def test_prompt_length():
+    doc_path = "example.txt"
+    with open(doc_path, "w", encoding="utf-8") as f:
+        # get wiki page about politician
+        r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
+        f.write(r.text)
+    docs = paperqa.Docs(llm=OpenAI(temperature=0.0, model_name="text-ada-001"))
+    docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
+    docs.query("What is the name of the politician?", length_prompt="25 words")
